<?php
/*
Damia - simple list of events management system using pXw4Pa

Copyright (C) 2007 (David Halliday)
http://david-halliday.co.uk/

uses: pXw4Pa - poor XML wrapper for PHP arrays v 1.0
http://pxw4pa.sourceforge.net/

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

// DEFAULT SETTINGS
$DefaultCalPath = "content.xml";

//import pXw4Pa for xml parsing
require 'pXw4Pa.php';

// INITIALISE
function InitialiseDamia(){
	//Global data items
	global $DefaultCalPath, $CalPath;
	global $Cal;
	
	//Set settings to defaults if they are blank
	if ($CalPath == "")$CalPath = $DefaultCalPath;
	
	if (file_exists($CalPath)){
		//Load menu from file (if file not already loaded)
		if ($Cal == "")$Cal=pXw4Pa_read($CalPath);
		
		//organise calendar in date order
		sort($Cal);
	}
	else{
		echo "<p><strong>ERROR:</strong> XML file not found: $CalPath</p>\n<p>Nothing will work till this file is found or added to in the administrative menu.</p>\n";
	}
	
	//comment out the below line to stop checking that the password is not the default "admin".
	CheckUserPW();
}

function CheckUserPW(){
	//this can be disabled in the "INITIALISE" function if you don't want to perform this check.
	//this is an important securety check and passwords on ANY system should NEVER be left as their default.
	//I also want to encourage users to change the username on the system so that it is harder for a potential hacker to guess their username/password combination using a brute force attack
	require 'admin/password.php';
	if ($pw == "admin"){
		echo "<h1>!!Warning!!</h1>\n";
		echo "<p>The default password is in use and needs to be changed!<br />\n If this password is not changed then it is easy for a hacker to break into your system. it is important that you edit the file on your web server:<br /><pre>admin/password.php</pre></p><p>You must chage the value marked 'xxx' (not including quotes) to something that you can remember as your password: <pre>\$pw = \"xxx\";</pre></p><p>It is also recommended to change the username to help prevent \"brute force\" attacks.</p>\n";
		echo "<h1>!!Warning!!</h1>\n";
	}
	//In a future version I may alter this so that the first time you load the site you are asked to specify a password and username. although this may have its own securety considerations.
}

function AddEvent($Date, $Name, $Desc, $Link){
	global $Cal;
	if (GetEventID($Date, $Name) == 0){
		$arraylength = count($Cal);
		$Cal[$arraylength + 1][date] = $Date;
		$Cal[$arraylength + 1][name] = $Name;
		$Cal[$arraylength + 1][desc] = $Desc;
		$Cal[$arraylength + 1][link] = $Link;
		sort($Cal);
		WriteChanges();
	}
	else{
		echo "<p><strong>ERROR:</strong> Event already exists: ". $Name ." on ". date("d/m/y", $Date) ."</p>\n<p>Duplicate event names &amp; dates aren't alowed";
	}
}

function EditEvent($Date, $Name, $Desc, $Link, $EventID){
	global $Cal;
	if ($EventID == "") echo "<p><strong>ERROR:</strong> EventID can't be null</p>\n";
	elseif($Date == "") echo "<p><strong>ERROR:</strong> Date can't be null</p>\n";
	elseif($Name == "") echo "<p><strong>ERROR:</strong> Name can't be null</p>\n";
	elseif($Cal[$EventID][date] == "") echo "<p><strong>ERROR:</strong> Event does not exist to edit: ". $Name ." on ". date("d/m/y", $Date) ."</p>\n";
	else{
		$Cal[$EventID][date] = $Date;
		$Cal[$EventID][name] = $Name;
		$Cal[$EventID][desc] = $Desc;
		$Cal[$EventID][link] = $Link;
		WriteChanges();
	}
}

function GetEventID($Timestamp, $Name){
	global $Cal;
	$arraylength = count($Cal);
	$ReturnInt = 0;
	for ($i = 1; $i <= $arraylength; $i++){
        if (($Cal[$i][name] == $Name)
        && ($Cal[$i][date] == $Timestamp)){
        	$toreturn = $i;
	    }
	}
	return $ReturnInt;
}

function DelEvent($EventID){
	global $Cal;
	unset($Cal[$EventID]);
	sort($Cal);
	WriteChanges();
}

function GetRadioList(){
	global $Cal;
	$arraylength = count($Cal);
	$ReturnString = "";
	for ($i = 0; $i < $arraylength; $i++){
        $ReturnString .= '<input type="radio" name="EventID" value="'. $i .'" />'. $Cal[$i][name].' '. date("d/m/y", $Cal[$i][date]) ."<br />\n";
	}
	return $ReturnString;
}

function WriteChanges(){
	global $Cal, $CalPath;
	sort($Cal);
	$answer=pXw4Pa_write($Cal,$CalPath);
	return $answer;
}

function GetTimestamp($day, $month, $year){
	//mktime(hour, minute, second, month, day, year, daylight savings time)
	return mktime(0, 0, 0, $month, $day, $year);
}

function GetCalItem($val){
	global $Cal;
	$ReturnString = "";
	$ReturnString .= '<tr><td rowspan="2" valign="top">'. date("d/m/y", $val[date]). '</td>';
	$ReturnString .= '<td><strong>';
	if ($val[link] != "") $ReturnString .= '<a href="'. str_replace ('&', '&amp;', $val[link]) . '">'; //replacing & with &amp; makes links standards compliant :)
	//if ($val[link] != "") $ReturnString .= '<a href="'. $val[link]. '">'; //original link wasn't W3C standards compliant
	$ReturnString .= $val[name];
	if ($val[link] != "") $ReturnString .= '</a>';
	$ReturnString .= '</strong></td></tr>';
	$ReturnString .= '<tr><td>'. $val[desc]."</td></tr>". "\n";
	
	return $ReturnString;
}

function GetAllEvents(){
	global $Cal;
	
	$ReturnString = "";
	
	$ReturnString .= "<table>\n";
	$ReturnString .= "<tr><th style=\"width: 50px\">Date</th><th>Event &amp; Details</th></tr>\n";

	foreach ($Cal as $key => $val) {
		$ReturnString .= GetCalItem($val);
	}
	
	$ReturnString .= "</table>\n";
	
	return stripslashes($ReturnString);
}

function GetFutureEvents(){
	global $Cal;
	
	$ReturnString = "";
	
	$ReturnString .= "<table>\n";
	$ReturnString .= "<tr><th style=\"width: 50px\">Date</th><th>Event &amp; Details</th></tr>\n";

	foreach ($Cal as $key => $val) {
		if($val[date] < mktime(0, 0, 0, date("m"), date("d"),   date("Y"))){
			//old event not interested in
		}
		else{
			$ReturnString .= GetCalItem($val);
		}
	}
	
	$ReturnString .= "</table>\n";
	
	return stripslashes($ReturnString);
}

function GetPastEvents(){
	global $Cal;
	
	$ReturnString = "";
	
	$ReturnString .= "<table>\n";
	$ReturnString .= "<tr><th style=\"width: 50px\">Date</th><th>Event &amp; Details</th></tr>\n";

	foreach ($Cal as $key => $val) {
		if($val[date] < mktime(0, 0, 0, date("m"), date("d"),   date("Y"))){
			$ReturnString .= GetCalItem($val);
		}
		else{
			//future events not shown here
		}
	}
	
	$ReturnString .= "</table>\n";
	
	return stripslashes($ReturnString);
}

//Run initialisation when damia is "required"
InitialiseDamia();

?>